<?php
// $Id: multiple_email_edit_page.inc,v 1.1.2.1 2010/06/04 02:39:46 shawndearmond Exp $

/**
 * @file
 * Functions for the page to edit an existing email address in the registry.
 */

 /**
  * Renders the page for adding a new email address
  *
  * @return string
  */
function multiple_email_edit_page($account, $eid) {
  menu_set_active_item('user/'. $account->uid .'/edit/email-addresses/edit/'. $eid);
  return drupal_get_form('multiple_email_edit_form', $account, $eid);
}

/**
 * Builds form for editing an email address
 *
 * @ingroup forms
 * @param object $account User object
 */
function multiple_email_edit_form(&$form_state, $account, $eid) {
  $email = multiple_email_get_address($eid);
  $form['email'] = array(
    '#type' => 'textfield',
    '#title' => t('Email Address'),
    '#required' => TRUE,
    '#default_value' => $email->email,
  );

  $form['eid'] = array(
    '#type' => 'value',
    '#value' => $eid,
  );

  $form['account'] = array(
    '#type' => 'value',
    '#value' => $account,
  );

  if (user_access('administer multiple emails')) {
    $form['confirm'] = array(
      '#type' => 'checkbox',
      '#title' => t('Activate this email.'),
    );
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * Validates multiple_email_edit_form
 *
 * @param string $form_id
 * @param array $form_values
 */
function multiple_email_edit_form_validate($form, &$form_state) {
  if (!valid_email_address($form_state['values']['email'])) {
    form_set_error('email', t('You must enter a valid email address!'));
  }
  elseif ($form_state['values']['email'] != $form['email']['#default_value'] && multiple_email_find_address($form_state['values']['email'])) {
    form_set_error('email', t('Entered address is already registered on this site.'));
  }
}

/**
 * Processes form submission of multiple_email_edit_form
 *
 * @param string $form_id
 * @param array $form_values
 */
function multiple_email_edit_form_submit($form, &$form_state) {
  $account = $form_state['values']['account'];
  $form_state['redirect'] = check_url('user/'. $account->uid .'/email-addresses');
  if ($form['email']['#default_value'] == $form_state['values']['email']) {
    drupal_set_message(t('No change was made to your email address.'));
  }
  else {
    if ($eid = multiple_email_register_email($account->uid, $form_state['values']['email'], FALSE, $form_state['values']['eid'])) {
      if (user_access('administer multiple emails') && $form_state['values']['confirm'] == TRUE) {
        $email = multiple_email_get_address($eid);
        multiple_email_confirm_email($email);
        drupal_set_message("The address {$email->email} has been confirmed!");
      }
      else {
        multiple_email_send_confirmation($account, multiple_email_get_address($eid));
        drupal_set_message(t("The email address '%email' has been added to your account and is awaiting confirmation.",
        array('%email' => $form_state['values']['email'])));
      }
    }
    else {
      form_set_error('', t("Error attempting to register '%email'", array('%email' => $form_state['values']['email'])));
    }
  }
}